# Security Policy

Thank you for taking the time to report a security issue. We are trying our best to make this project safe for everyone. We appreciate your efforts to disclose the issue responsibly and will make every effort to acknowledge your contributions.

## Reporting a vulnerability

**Please do not report security vulnerabilities through public GitHub issues.**

If you believe you have found a security vulnerability, please send an email to edwin@oasysai.com. Please include as many details as possible, these may include:

- Impact of the vulnerability.
- Steps to reproduce.
- Possible solutions.
- Location of the vulnerability like file or line number.
- If applicable, proof-of-concept or exploit code.
